JSDoc: Class: Plottable

# Class: Plottable

## Plottable

Plottable

Represents a sample and the associated metadata in the ordination space.

## Constructor

#### new Plottable(name, metadata, coordinates, idxopt, ciopt) → {Plottable}

##### Parameters:

Name | Type | Attributes | Default | Description
--- | --- | --- | --- | ---
`name` | string |  |  | A string indicating the name of the sample.
`metadata` | Array.<string> |  |  | An Array of strings with the metadata values.
`coordinates` | Array.<float> |  |  | An Array of floats indicating the position in space where this sample is located.
`idx` | integer | <optional> | -1 | An integer representing the index where the object is located in a DecompositionModel.
`ci` | Array.<float> | <optional> | [] | An array of floats indicating the confidence intervals in each dimension.

Source:
  - model.js, line 25

##### Returns:

Type
  Plottable

### Members

#### ci :Array.<float>

Confidence intervals.

##### Type:

- Array.<float>

Source:
  - model.js, line 51

#### coordinates :Array.<float>

Position of the sample in the N-dimensional space.

##### Type:

- Array.<float>

Source:
  - model.js, line 40

#### idx :integer

The index of the sample in the array of meshes.

##### Type:

- integer

Source:
  - model.js, line 46

#### metadata :Array.<string>

Metadata values for the sample.

##### Type:

- Array.<string>

Source:
  - model.js, line 35

#### name :string

Sample name.

##### Type:

- string

Source:
  - model.js, line 30

### Methods

#### toString() → {string}

Helper method to convert a Plottable into a string.

Source:
  - model.js, line 70

##### Returns:

A string describing the Plottable object.

Type
  string